// TESampleCS
// This Test is a simple demo just for showing a possibile use of TrIDEngine
// (C) 2004-2005 By Marco Pontello - http://mark0.net

using System;
using System.IO;

// Define an alias for TrIDEngine class
using TrID = TrIDEngine.TrIDEngine;

namespace TESampleCS
{
    class Class1
    {
        static void Main(string[] args)
        {
            // Create the 'core' object
            TrID.PatternEngine PE = new TrID.PatternEngine();

            // A little intro...
            Console.WriteLine("");
            Console.WriteLine("TESampleCS - TrIDEngine Sample/Test");
            Console.WriteLine("(TrIDEngine v" + PE.Version + ")");
            Console.WriteLine("-----------------------------------");
            Console.WriteLine("This demo will load all *.trid.xml defs in the current directory,");
            Console.WriteLine("and then analyze a file named 'TEST.DAT'");
            Console.WriteLine("");

            // Check for all the defs in current directory
            string sCurDir = Directory.GetCurrentDirectory();
            Console.WriteLine("Checking definitions files...");
            string[] sDefsList = Directory.GetFiles(sCurDir, "*.trid.xml");
            if (sDefsList.Length == 0)
            {
                Console.WriteLine("No definitions available!");
                Console.WriteLine("Download an up to date defs library from http://mark0.ngi.it");
                Environment.Exit(1);
            }

            // Submit all defs to the engine
            for (int i = 0; i < sDefsList.Length; i++)
            {
                string sDefFile = sDefsList[i];
                Console.WriteLine(Path.GetFileName(sDefFile));
                PE.LoadDefinition(sDefFile);
            }

			// This is just for showing how to save & reuse the loaded defs
			System.Collections.ArrayList MyDefPack;
			MyDefPack = (System.Collections.ArrayList) PE.GetDefs();
			// Clear all the definitions in memory...
			PE.ClearDefinitions();
			// ... Reload them!
			PE.SetDefs(ref MyDefPack);

            Console.WriteLine("");
            Console.WriteLine("Analyzing...");

            try
            {
                // Submit the file to analyze
                PE.SubmitFile("TEST.DAT");

				// Check if the file is a binary one; if not, display a warning
				if(!PE.IsBinary())
				{
					Console.WriteLine("Warning: TrID is better suited for binary files!");
				}

				// Start the identification process
                // (this will show a demo-reminder with the demo ver. of TrIDEngine.DLL)
                PE.Analyze();
            }

            catch
            {
                Console.WriteLine("* Error: Unable to open file 'TEST.DAT'");
                Console.WriteLine("  (maybe it's locked by another process?!)");
                Environment.Exit(1);
            }

            // Create a container of the proper type to get the firsts 5 results
            // in the extended form (instead of simple strings)
            TrID.tResult[] ExtResults;
            ExtResults = PE.GetResultsData(5);

            // Show the results...
            for (int i = 0; i < ExtResults.Length; i++)
            {
                TrID.tResult Result = ExtResults[i];

                Console.Write(Result.Points + " ");
                Console.Write(Result.ExtraInfo.FileExt + " ");
                Console.WriteLine(Result.ExtraInfo.FileType);
            }
            Console.WriteLine("");
        }
    }
}
